@@ -52,7 +52,7 @@ def make_node(
     )
     graph_node_input_2 = get_constant_or_variable(
         graph_node.inputs[1],
-        before_op_output_shape_trans,
+        before_op_output_shape_trans=False,
     )
     graph_node_input_3 = get_constant_or_variable(
         graph_node.inputs[2],
@@ -69,60 +69,14 @@ def make_node(
     updates_tensor = tf_layers_dict[graph_node_input_3.name]['tf_node'] \
         if isinstance(graph_node_input_3, gs.Variable) else graph_node_input_3
 
-    # Inverted workaround to avoid shape errors as much as possible
-    if not before_op_output_shape_trans \
-        and list(graph_node.inputs[0].shape) != list(input_tensor.shape) \
-        and list(graph_node.inputs[1].shape) == list(indices_tensor.shape) \
-        and list(graph_node.inputs[2].shape) == list(updates_tensor.shape):
-
-        input_tensor_shape = input_tensor.shape
-        input_tensor_rank = len(input_tensor_shape)
-        indices_tensor_shape = indices_tensor.shape
-        updates_tensor_shape = updates_tensor.shape
-        updates_tensor_rank = len(updates_tensor_shape)
-        # Obtaining the number of ranks to be operated
-        number_of_ranks_operate = indices_tensor_shape[-1]
-        # 1. The number of ranks to be operated must be numeric
-        # 2. The number of ranks to be operated on must match the number of ranks in the input tensor
-        # 3. The number of ranks to be operated on must match the number of ranks in the tensor for updating
-        # 4. Forced NHWC conversion if all the above conditions are met
-        if isinstance(number_of_ranks_operate, int) \
-            and input_tensor_rank == number_of_ranks_operate \
-            and updates_tensor_rank == number_of_ranks_operate:
-
-            indices_convertion_table = [0] + [i for i in range(2, input_tensor_rank)] + [1, input_tensor_rank]
-            indices_gather_table = [0] + [i for i in range(2, input_tensor_rank)] + [1]
-            updates_convertion_table = [0] + [i for i in range(2, input_tensor_rank)] + [1]
-            # Corrects tensor shape discrepancies
-            if isinstance(indices_tensor, np.ndarray):
-                indices_tensor = indices_tensor.transpose(indices_convertion_table)
-            elif tf.keras.backend.is_keras_tensor(indices_tensor):
-                indices_tensor = tf.transpose(
-                    a=indices_tensor,
-                    perm=indices_convertion_table,
-                )
-            if isinstance(updates_tensor, np.ndarray):
-                updates_tensor = updates_tensor.transpose(updates_convertion_table)
-            elif tf.keras.backend.is_keras_tensor(updates_tensor):
-                updates_tensor = tf.transpose(
-                    a=updates_tensor,
-                    perm=updates_convertion_table,
-                )
-            # Transposition of indices
-            if isinstance(indices_tensor, np.ndarray):
-                indices_tensor = indices_tensor[..., indices_gather_table]
-            elif tf.keras.backend.is_keras_tensor(indices_tensor):
-                indices_tensor = tf.gather(
-                    params=indices_tensor,
-                    indices=indices_gather_table,
-                    axis=-1,
-                )
-
     # Preserving Graph Structure (Dict)
     tf_layers_dict[graph_node_output.name] = {
         'optype': graph_node.op,
         'shape': shape,
         'dtype': dtype,
+        'nhwc': tf_layers_dict[graph_node_input_1.name]['nhwc'] \
+            if isinstance(graph_node_input_1, gs.Variable) \
+                and 'nhwc' in tf_layers_dict[graph_node_input_1.name].keys() else False
     }
 
     # Pre-process transpose
@@ -145,6 +99,61 @@ def make_node(
         **kwargs,
     )
 
+    # When NHWC is fixed, return to NCHW format before processing.
+    data_nhwc = tf_layers_dict[graph_node_input_1.name]['nhwc'] \
+        if isinstance(graph_node_input_1, gs.Variable) \
+            and 'nhwc' in tf_layers_dict[graph_node_input_1.name].keys() else False
+    indices_nhwc = tf_layers_dict[graph_node_input_2.name]['nhwc'] \
+        if isinstance(graph_node_input_2, gs.Variable) \
+            and 'nhwc' in tf_layers_dict[graph_node_input_2.name].keys() else False
+    updates_nhwc = tf_layers_dict[graph_node_input_3.name]['nhwc'] \
+        if isinstance(graph_node_input_3, gs.Variable) \
+            and 'nhwc' in tf_layers_dict[graph_node_input_3.name].keys() else False
+
+    pre_input_tensor_shape = input_tensor.shape
+
+    # NHWC -> NCHW
+    nchw = not (data_nhwc or indices_nhwc or updates_nhwc)
+    ## data
+    if data_nhwc \
+        and len(input_tensor.shape) >= 3:
+        perm = [0, len(input_tensor.shape)-1] + [i for i in range(1, len(input_tensor.shape)-1)]
+        input_tensor = tf.transpose(a=input_tensor, perm=perm)
+        nchw = True
+    elif not data_nhwc \
+        and len(input_tensor.shape) >= 3 \
+        and graph_node.inputs[0].shape is not None \
+        and input_tensor.shape != graph_node.inputs[0].shape:
+        perm = [0, len(input_tensor.shape)-1] + [i for i in range(1, len(input_tensor.shape)-1)]
+        input_tensor = tf.transpose(a=input_tensor, perm=perm)
+        nchw = True
+    ## indices
+    if indices_nhwc \
+        and len(indices_tensor.shape) >= 4:
+        perm = [0, len(indices_tensor.shape)-2] + [i for i in range(1, len(indices_tensor.shape)-2)] + [len(indices_tensor.shape)-1]
+        indices_tensor = tf.transpose(a=indices_tensor, perm=perm)
+        nchw = True
+    elif not indices_nhwc \
+        and len(indices_tensor.shape) >= 4 \
+        and graph_node.inputs[1].shape is not None \
+        and indices_tensor.shape != graph_node.inputs[1].shape:
+        perm = [0, len(indices_tensor.shape)-2] + [i for i in range(1, len(indices_tensor.shape)-2)] + [len(indices_tensor.shape)-1]
+        indices_tensor = tf.transpose(a=indices_tensor, perm=perm)
+        nchw = True
+    ## updates
+    if updates_nhwc \
+        and len(updates_tensor.shape) >= 3:
+        perm = [0, len(updates_tensor.shape)-1] + [i for i in range(1, len(updates_tensor.shape)-1)]
+        updates_tensor = tf.transpose(a=updates_tensor, perm=perm)
+        nchw = True
+    elif not updates_nhwc \
+        and len(updates_tensor.shape) >= 3 \
+        and graph_node.inputs[2].shape is not None \
+        and updates_tensor.shape != graph_node.inputs[2].shape:
+        perm = [0, len(updates_tensor.shape)-1] + [i for i in range(1, len(updates_tensor.shape)-1)]
+        updates_tensor = tf.transpose(a=updates_tensor, perm=perm)
+        nchw = True
+
     # Complex ScatterND -> Simple ScatterND
     simple_scatternd = False
     # Verify if negative numbers need to be converted to positive numbers
@@ -172,6 +181,7 @@ def make_node(
             indices=indices_tensor,
         )
 
+    # normal scatter_nd_update
     tf_layers_dict[graph_node_output.name]['tf_node'] = \
         tf.tensor_scatter_nd_update(
             tensor=input_tensor \
@@ -186,6 +196,17 @@ def make_node(
             name=graph_node.name,
         )
 
+    # NCHW -> NHWC
+    if nchw \
+        and len(input_tensor.shape) >= 3 \
+        and pre_input_tensor_shape != tf_layers_dict[graph_node_output.name]['tf_node'].shape:
+        perm = [0] + [i for i in range(2, len(input_tensor.shape))] + [1]
+        tf_layers_dict[graph_node_output.name]['tf_node'] = \
+            tf.transpose(
+                a=tf_layers_dict[graph_node_output.name]['tf_node'],
+                perm=perm,
+            )
+
     # Post-process transpose
     tf_layers_dict[graph_node_output.name]['tf_node'] = post_process_transpose(
         value_before_transpose=tf_layers_dict[graph_node_output.name]['tf_node'],
