@@ -12,10 +12,7 @@ from onnx2tf.utils.common_functions import (
     get_replacement_parameter,
     pre_process_transpose,
     post_process_transpose,
-    make_tf_partial_model_inputs,
-    dummy_tf_inference,
 )
-from typing import Any, Dict, List
 
 
 @print_node_info
@@ -79,59 +76,12 @@ def make_node(
         and before_trans_shape != after_trans_shape:
         tf_layers_dict[graph_node_output.name].pop('nhwc')
 
-    # Generate input OPs for TensorFlow subgraphs
-    # For inference testing on OP stand-alone
-    if kwargs['acc_check']:
-        tf_partial_model_inputs: List[tf.keras.Input] = \
-            make_tf_partial_model_inputs(
-                input_tensors=[input_tensor]
-            )
-        tf_partial_model_outputs = None
-
     # Generation of TF OP
-    ### Overall model
     tf_layers_dict[graph_node_output.name]['tf_node'] = \
         tf.nn.sigmoid(
             x=input_tensor,
             name=graph_node.name,
         )
-    ### Partial model
-    if kwargs['acc_check'] and tf_partial_model_inputs is not None:
-        tf_partial_model_outputs = \
-            [
-                tf.nn.sigmoid(
-                    x=tf_partial_model_inputs[0],
-                )
-            ]
-        tf_partial_model = tf.keras.Model(
-            inputs=tf_partial_model_inputs,
-            outputs=tf_partial_model_outputs,
-        )
-        test_data = None
-        if not isinstance(input_tensor, np.ndarray):
-            if not isinstance(graph_node_input, np.ndarray) \
-                and graph_node_input.name in tf_layers_dict \
-                and 'verification_data' in tf_layers_dict[graph_node_input.name].keys():
-                test_data: np.ndarray = tf_layers_dict[graph_node_input.name]['verification_data']
-            elif isinstance(graph_node_input, np.ndarray):
-                test_data: np.ndarray = graph_node_input
-            else:
-                test_data = None
-        else:
-            test_data = input_tensor
-        tf_partial_model_result_infos: Dict[Any] = dummy_tf_inference(
-            model=tf_partial_model,
-            inputs=tf_partial_model_inputs,
-            verification_datas=[
-                test_data
-            ]
-        )
-        tf_layers_dict[graph_node_output.name]['verification_data'] = \
-            list(tf_partial_model_result_infos.values())[0]
-        del tf_partial_model
-        del tf_partial_model_inputs
-        del tf_partial_model_outputs
-        del test_data
 
     # Post-process transpose
     before_trans_shape = tf_layers_dict[graph_node_output.name]['tf_node'].shape
