@@ -3,9 +3,9 @@ from typing import List
 
 random.seed(0)
 import numpy as np
-
 np.random.seed(0)
 import tensorflow as tf
+import tf_keras
 import onnx_graphsurgeon as gs
 from onnx2tf.utils.common_functions import (
     get_constant_or_variable,
@@ -15,10 +15,10 @@ from onnx2tf.utils.common_functions import (
     get_replacement_parameter,
     pre_process_transpose,
 )
-from onnx2tf.utils.colors import Color
+from onnx2tf.utils.logging import Color
 
 
-class tfUnique(tf.keras.layers.Layer):
+class tfUnique(tf_keras.layers.Layer):
 
     def __init__(self):
         super(tfUnique, self).__init__()
@@ -103,7 +103,7 @@ def make_node(
     if sorted:
         # TODO: implement sort
         error_msg = f'' + \
-                    f'{Color.RED}WARNING:{Color.RESET} ' + \
+                    Color.RED(f'WARNING:') + ' ' + \
                     f'Sort option in Unique ops is not implemented yet.'
         print(error_msg)
         assert False, error_msg
